@@ -1,7 +1,7 @@
 package LinuxMint::Releases;
 
-our $DATE = '2015-10-06'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2016-02-24'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -354,19 +354,19 @@ our $data = do {
    {
      apache_httpd_version => "--",
      bash_version         => 4.3,
-     code_name            => "rafaela",
+     code_name            => "rosa",
      eoldate              => "2019-04",
-     linux_version        => 3.16,
+     linux_version        => 3.19,
      mariadb_version      => "--",
      mysql_version        => "--",
      nginx_version        => undef,
      perl_version         => "5.18.2",
      php_version          => "--",
      postgresql_version   => "--",
-     python_version       => "2.7.5",
-     reldate              => "2015-06-30",
+     python_version       => "2.7.6",
+     reldate              => "2015-12-04",
      ruby_version         => undef,
-     version              => 17.2,
+     version              => 17.3,
    },
  ]
 
@@ -395,7 +395,7 @@ LinuxMint::Releases - List LinuxMint releases
 
 =head1 VERSION
 
-This document describes version 0.01 of LinuxMint::Releases (from Perl distribution LinuxMint-Releases), released on 2015-10-06.
+This document describes version 0.02 of LinuxMint::Releases (from Perl distribution LinuxMint-Releases), released on 2016-02-24.
 
 =head1 SYNOPSIS
 
@@ -1050,7 +1050,7 @@ Only return records where the 'ruby_version' field is less than specified value.
 
 Only return records where the 'ruby_version' field is greater than specified value.
 
-=item * B<sort> => I<str>
+=item * B<sort> => I<array[str]>
 
 Order records according to certain field(s).
 
@@ -1122,16 +1122,6 @@ that contains extra information.
 
 Return value:  (any)
 
-=head1 SEE ALSO
-
-L<Debian::Releases>
-
-L<Ubuntu::Releases>
-
-L<RedHat::Releases>
-
-L<CentOS::Releases>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/LinuxMint-Releases>.
@@ -1148,13 +1138,23 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Debian::Releases>
+
+L<Ubuntu::Releases>
+
+L<RedHat::Releases>
+
+L<CentOS::Releases>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
